summaryrefslogtreecommitdiffstats
path: root/kpat/freecell-solver/tests.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpat/freecell-solver/tests.h')
-rw-r--r--kpat/freecell-solver/tests.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kpat/freecell-solver/tests.h b/kpat/freecell-solver/tests.h
index ce0b35b5..0293ed85 100644
--- a/kpat/freecell-solver/tests.h
+++ b/kpat/freecell-solver/tests.h
@@ -66,8 +66,8 @@ extern "C" {
ptr_new_state_with_locations->depth = ptr_state_with_locations->depth + 1; \
/* Mark this state as a state that was not yet visited */ \
ptr_new_state_with_locations->visited = 0; \
- /* It's a newly created state which does not have children yet. */ \
- ptr_new_state_with_locations->num_active_children = 0; \
+ /* It's a newly created state which does not have tqchildren yet. */ \
+ ptr_new_state_with_locations->num_active_tqchildren = 0; \
memset(ptr_new_state_with_locations->scan_visited, '\0', \
sizeof(ptr_new_state_with_locations->scan_visited) \
); \
@@ -119,13 +119,13 @@ fcs_move_stack_push(moves, temp_move); \
); \
if (!(existing_state->visited & FCS_VISITED_DEAD_END)) \
{ \
- if ((--existing_state->parent->num_active_children) == 0) \
+ if ((--existing_state->parent->num_active_tqchildren) == 0) \
{ \
mark_as_dead_end( \
existing_state->parent \
); \
} \
- ptr_state_with_locations->num_active_children++; \
+ ptr_state_with_locations->num_active_tqchildren++; \
} \
existing_state->parent = ptr_state_with_locations; \
existing_state->depth = ptr_state_with_locations->depth + 1; \